#
# spec file for package Bottles
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global appid com.usebottles.bottles
Name:           Bottles
Version:        51.15
Release:        1.1
Summary:        Easily manage wineprefix using environments
License:        GPL-3.0-or-later
Group:          System/Emulators/Other
URL:            https://usebottles.com/
Source0:        https://github.com/bottlesdevs/Bottles/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         disable-core-preferences.patch
BuildRequires:  blueprint-compiler
BuildRequires:  fdupes
BuildRequires:  gtk4-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(python3)
Requires:       ImageMagick
Requires:       cabextract
Requires:       dconf
Requires:       gtk4
Requires:       libadwaita-1-0 >= 1.2
Requires:       p7zip
Requires:       patool
Requires:       python3-Markdown
Requires:       python3-PyYAML
Requires:       python3-chardet
Requires:       python3-fvs
Requires:       python3-gobject
Requires:       python3-icoextract
Requires:       python3-pathvalidate
Requires:       python3-pefile
Requires:       python3-pycurl
Requires:       python3-requests
Requires:       typelib-1_0-Adw-1 >= 1.2
Requires:       typelib-1_0-GtkSource-4
Requires:       typelib-1_0-GtkSource-5
Requires:       typelib-1_0-Handy-1_0
Requires:       typelib-1_0-WebKit2-4_0
Requires:       vkbasalt-cli
Requires:       xdpyinfo
Suggests:       wine
Suggests:       dxvk
Suggests:       gamemoded
Suggests:       libbsd
Suggests:       libcaca
Suggests:       libcapi20
Suggests:       libgamemode0
Suggests:       libgamemodeauto0
Suggests:       libpcap1
Suggests:       libvkd3d-shader1
Suggests:       libvkd3d1
Suggests:       samba-winbind
Suggests:       vkbasalt
BuildArch:      noarch
Obsoletes:      bottles >= 2022
Provides:       bottles = %{version}-%{release}
%lang_package

%description
Bottles is an application that allows you to easily manage windows prefixes on your favorite Linux distribution.

Windows prefixes are environments where it is possible to run Windows software using runners.
Runners are compatibility layers capable of running Windows applications on Linux systems.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file %{appid}
%find_lang bottles

%fdupes %{buildroot}

%files
%license COPYING.md
%doc README.md
%{_bindir}/bottles
%{_bindir}/bottles-cli
%{_datadir}/bottles
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}*.svg
%{_datadir}/icons/hicolor/*/apps/bottle-symbolic.svg
%{_datadir}/icons/hicolor/symbolic/apps/bottles-steam-symbolic.svg
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml

%files lang -f bottles.lang

%changelog
* Tue Oct 15 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 51.15:
  * fix a bug, where win11 as on option was not shown
* Sun Oct 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 51.14:
  * New "Native" Force Stop all Processes option
  * Provide bottle Path as env var
  * Win11 support
  * feat: support for personal repos
  * Update manifest (important)
  * Update GNOME runtime and Wine base
  * Translations update
  * Add Pre-Run script to launch options
  * bottles with a different name and path weren't runnable through bottle picker
  * fix: "bottles:run/" uri processing
* Wed Jul 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to version 51.13:
  * Fixed crash on starting executables via the file manager
* Wed Jul 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update version 51.12:
  * Support d3d8 via dxvk
  * Removed @lru_cache decorator from the Paths class, plus minor typing fixes
  * Fixed crash on startup
  * Updated GNOME runtime in manifest
  * Moved chattr_f function to appropriate class
  * Improved performance by using case-fold for drive_c when available
  * Fixed Gamescope options arguments
  * Added option to skip checksum when installing dependencies
  * Fixed issue where bottles with spaces in name couldn't be run through bottle picker
  * Fixed issue where kgx Launch with terminal was not working
  * Repaired SyntaxWarning in generic.py (invalid escape sequence '\d') when starting bottles from CLI
  * Fixed misspelled media type (application/x-ms-dos-executable)
  * Switched to add_pattern from add_mime_type to resolve file filter issues on certain Linux distributions
  * Added TryExec to desktop entry
* Sat Mar  9 2024 Richard Rahl <rrahl0@proton.me>
- add versioned provides and obsolete
* Sat Feb 24 2024 Richard Rahl <rrahl0@proton.me>
- disable the core view in preferences like flatpak
* Wed Feb 21 2024 Richard Rahl <rrahl0@proton.me>
- update to 51.11
  * Fix running programs via CLI
  * Fix handling of empty program arguments
  * Removed obsolete faudio dependency from the environment
  * Various bug fixes and refactoring
* Wed Feb  7 2024 Richard Rahl <rrahl0@proton.me>
- rename bottles to Bottles to get the official naming
- seperate out the language files into their own package
* Fri Jan 26 2024 Richard Rahl <rrahl0@proton.me>
- switch to actual real version
- remove the second lang files in %%files
- switch to python3- from python%%python_version_nodots
- remove gtk3 from the BuildRequires and Required list
- cleanup formatting
- add fdupes for duplicates
* Sat Dec 23 2023 Imo Hester <vortex@z-ray.de>
- Fix build errors for Tumbleweed
- Update to version 51.10
  * fix: LatencyFlex by @koplo199 in #3057
  * fix: Wrong programs name and empty program entries by @koplo199 in #3056
  * Use some dependencies in samples by @EliasOfWaffle in #2900
  * fixed steam runtime path in WineCommand:get_cmd by @holyfight6 in #3066
  * fix: Do not show success with failed dependencies install by @koplo199 in #3062
  * automation: Use dependabot to update actions by @koplo199 in #3072
  * Translations update from Hosted Weblate by @weblate in #2883
  * Library changes & Quit fix by @RozeFound in #2906
  * Improve bad connections handling by @dartvader316 in #3075
  * po: fix duplicate strings, update POT file by @kbdharun in #2977
  * Minor improvements by @koplo199 in #3102
  * Revert "Minor improvements (#3102)" by @koplo199 in #3110
  * Add WAYLAND_SOCKET check by @xioren in #3153
  * Fail on unsuccessful cab_extract download by @xioren in #3150
  * Allow special characters in bottle names by @cybin in #3140
  * data: Mark release descriptions as untranslatable by @sabriunal in #3113
  * Allow dependencies to be installed in 32 bits bottle by @koplo199 in #3101
  * fix: MangoHud, gamescope and vkBasalt versions by @koplo199 in #3112
  * fix: Various bug fixes and cleanups by @koplo199 in #3117
  * Add "all files" to the "add shortcuts" file picker by @rafaelhipercg in #3204
  * 51.10 by @koplo199 in #3099
* Mon Aug 21 2023 Imo Hester <vortex@z-ray.de>
- Update to version 51.9
  * fix: Components/Runners not showing when pre-release is off and steam runtime compatibility with wine runners by @koplo199 in #3049
* Mon Aug 21 2023 Imo Hester <vortex@z-ray.de>
- Update to version 51.8
- Update to version 51.7
  * Add APP_NAME to configuration by @ItsJamie9494 in #2876
  * Improve WineCommand.run() by @StoneMoe in #2748
  * Block the use of GTK_THEME in bottles by @axtloss in #2886
  * main: Fix crash when GTK_THEME doesn't exist by @TheEvilSkeleton in #2893
  * cli: Fix app version error by @TheEvilSkeleton in #2894
  * Fix forum URL by @GreenCappuccino in #2899
  * Test SonarQube by @pietrodicaprio in #2916
  * Fix typos in metainfo by @kbdharun in #2867
  * get/set_active instead of get/set_state for switch by @kryotek777 in #2882
  * readme: Replace Telegram with Discord by @TheEvilSkeleton in #2923
  * Remove the package maintainer section from README by @MonsterObserver in #2974
  * misc: Improve README and build instructions to favor Flatpak by @TheEvilSkeleton in #3004
  * winecommand: Fix LatencyFleX enablement by @Joshua-Ashton in #2993
  * chore: Remove unused imports by @TheEvilSkeleton in #3005
  * frontend: Use active instead of state property by @TheEvilSkeleton in #3006
  * frontend: Rename "Bottle Name" to "Name" by @TheEvilSkeleton in #3008
  * fix: Offline components and runners not manageable by @koplo199 in #2962
  * Fix adding new executables to bottle and updating launch options by @pgasior in #2909
  * Fixed ability to change drive location by @v72nico in #2944
  * fix: Steam and Proton usage by @koplo199 in #2961
  * chore: Clean and update manifest + automation by @koplo199 in #2964
  * Update manifest (important) by @github-actions in #3033
  * workflow: Use more secure pull_request trigger and fix SonarQube by @koplo199 in #3034
  * configuration: Set python version to 3 in sonar-project.properties by @koplo199 in #3044
* Wed May 31 2023 Imo Hester <vortex@z-ray.de>
- Make wine a suggested dependency
- Remove css patch
* Mon May 15 2023 Imo Hester <vortex@z-ray.de>
- Update to version 51.6
  * frontend: Display toast when executing by @TheEvilSkeleton in #2726
  * Backend rewrite by @StoneMoe in #2730
  * frontend: Rename create bottle button in list by @TheEvilSkeleton in #2735
  * Make window remember dimensions by @RozeFound in #2807
  * Use proper app icon naming by @kra-mo in #2814
  * frontend: Fix applying style classes by @jannuary in #2809
  * flatpak: Update runtime by @TheEvilSkeleton in #2815
  * fix: Steam shortcut uses Bottle's path instead of name by @kryotek777 in #2754
  * Change General icon and extern syntax by @TheEvilSkeleton in #2827
  * workflows/*: Bump version of actions by @kbdharun in #2834
  * po: update POTFILES, PO files; make translator credits a translatable string by @kbdharun in #2823
  * pylint-commenter.yml: fix build by @kbdharun in #2836
  * pylint-commenter.yml: revert to old version to fix workflow by @kbdharun in #2838
  * appstream: Update information by @TheEvilSkeleton in #2687
  * Minor improvements and fixes to library by @RozeFound in #2816
  * Add gitattributes, sync PO files from recent Weblate PR manually by @kbdharun in #2837
  * Remove Futex2 sync by @SuperSamus in #2847
  * Fix backend rewrite by @StoneMoe in #2749
  * Add support for newer vkd3d-proton + bug fix by @koplo199 in #2824
  * fix: Use correct xdpyinfo URL by @TheEvilSkeleton in #2859
  * [code]: Add pytest action by @Kinsteen in #2743
  * Initial mypy support by @qarmin in #2747
  * Use bottle name instead of path in launch options when adding a Steam shortcut by @Kinsteen in #2858
  * Download stable component on first launch by @koplo199 in #2846
* Wed Apr 12 2023 Imo Hester <vortex@z-ray.de>
- Changed vkbasalt-cli dependency
* Thu Mar 30 2023 Imo Hester <vortex@z-ray.de>
- Fix GTK 4.10 css
- Remove python-Pillow from requirements
* Thu Mar 30 2023 Imo Hester <vortex@z-ray.de>
- Update to version 51.5
  * Correct release version
- Update to version 51.4
  * Add more update information and correct changelog version
- Update to version 51.3
  * fix: Unable to add Steam shortcut
  * fix: duplicate installed dependencies after reinstall
  * make BottleConfig Json serializable
  * Fix patool double extraction again
- Update to version 51.2
  * Correct release version
- Update to version 51.1
  * Fix crash when creating a bottle
- Update to version 51.0
  * Translations update from Hosted Weblate
  * frontend: Replace emote-love with library icon
  * frontend: Remove Create a Bottle description
  * frontend: Ability to name the Bottle with special characters + duplicate bug fix
  * frontend: Fix various library crashes and empty library items
  * code: Add Pylint GitHub Actions against PRs
  * fix: Fix GTK critical error at startup
  * misc: Use media types instead of patterns
  * fix/urgent: downloads not working if no terminal attached
  * fix: remove add to library button if already in library
  * misc: Update issue forms
  * Network issue template
  * code: better Pylint
  * Migrate Config from dict to object
  * Add GitHub Action close issues if people are using a too old version
  * fix incorrect text codec detection
  * fix: Fix patool double extracting when not needed
  * fix: Invert get_file() and get_path()
  * Remake New Bottle dialog
  * frontend: Add toast for "Run Executable"
  * misc: Add information using bottles-cli
  * fix: Error when adding shortcut to Steam
  * fix: Create bottle crashing if no Nvidia GPU and NVAPI installs
  * Update translation files
  * fix inconsistent return type for WineCommand
  * flatpak: Remove Pillow
  * frontend: Gracefully handle ridiculous names
  * Make sure ListView gets updated properly when deleting a bottle
  * fix: Properly set paths for launch options dialog
  * fix terminal download progress crash
  * Don't enable Steam Runtime when switching to wine-ge-proton
* Thu Jan 19 2023 Imo Hester <vortex@z-ray.de>
- Update to version 50.2
  * fix: downloads not working if no terminal
- Update to version 50.1
  * fix: update library entries when renaming a bottle
  * fix: critical error when not using a Nvidia GPU
- Update to version 50
  * frontend: Gamescope improvements
  * Fix typos in strings and update translations
  * Translations update from Hosted Weblate
  * fix: dependency replace_font step
  * backend: Improve health check
  * misc: Remove JSON manifest
  * Frontend: Updated link for connection checking
  * frontend: More improvements for Gamescope
  * fix: create_bottle_from_config() nvapi check
  * fix: ComponentManager.install() deadlock
  * fix: wrong exception catching using pycurl
  * fix: slow replace_font
  * fix: replace spin-lock with threading.Lock
  * feat: support userdir/ placeholder for installers checks
  * fix: being able to use local repos with pycurl
  * misc: improve check_runners() log
  * fix: onboard dialog shows "All ready" when not ready
  * misc: Update and improve packaging
  * feat: enable VKD3D in the Gaming environment
  * feat: async fetch of components, installers and dependencies
  * fix: Bottles crash if bad encoding in Steam file
  * fix: Components not updating when install in UI
  * frontend: Improve sentence in installers
  * frontend: Fix FSR
  * misc: Update contributing information
  * frontend: smoother UI with async code
  * Don't override GST_PLUGIN_SYSTEM_PATH if runner doesn't bundle GStreamer
  * fsr: Fix more FSR related issues
  * frontend: make app name untranslatable, disambiguate Bottles & bottles
  * fix: wrong call to update_programs()
  * fix: hint texts
  * frontend: Remove FileChooser class
  * fix: add dest to cabextract on local files
  * frontend: Port primary menu to MenuModel
  * term-ui: dynamic length of progress bar according to terminal size
  * Addresses bug from patoolib
  * fix: wrong combo selected for VKD3D
  * fix: broken back button if DXVK and VKD3D are disabled
  * ui: Make VKD3D not enable-able without DXVK
  * backend: Add import_bundle on dependency installation
  * fix: nvngx.dll not copied under Flatpak, UI consistency
  * fix: Add runner libs to fix embedded GStreamer not finding them
* Thu Dec 22 2022 Imo Hester <vortex@z-ray.de>
- New dependency pycurl
- Update to version 2022.12.14.1
  * Fix typos
  * frontend: Add tooltips for extensions
  * misc: Cleanup flatpak manifest
  * frontend: Fix LibraryEntry removal with no parent
  * backend: Force terminate wineserver on bottle deletion
  * backend: Avoid caching dicts
  * misc: Allow bwrap instance sharing
- Update to version 2022.12.14
  * Translations update from Hosted Weblate
  * Fix Latencyflex not disabling correctly and environment variables
  * misc: Update screenshots
  * misc: Update issue form
  * Fix bottle name space error
  * Fixed setup of dll overrides on bottle start
  * Fix missing cwd variable when launching a program with terminal
  * Fix GStreamer system path, and added a switch in bottle
  * CVE-2007-4559 Patch
  * Update translation files
  * Added new bottles CDN service
  * frontend/cli: run: Allow multiple arguments to pass to executable
  * Fix bottle renaming
  * Revamp Library page
  * General backend improvements
* Sun Nov 20 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.11.14
  * backend: Fix Gamescope arguments
  * backend: Fix DLSS
  * cli: Fix ignored name when adding program via CLI
  * Translations update from Hosted Weblate
  * nvapi hotfix
  * frontend: Improve bottle details view
  * frontend: Redesign details view
  * backend: Don't use d3d10 & d3d10_1 dll's from dxvk
  * frontend: Add grade tooltips
  * misc: Use metainfo
  * frontend: QoL improvements
  * Header Capitalization and localization fixes
  * app: Add accel for window.close and chain up vfunc
  * Fix installer completion
  * about: Add libraries to acknowledgements and remove slashes
  * frontend: Rewrite vkBasalt frontend
  * Settings Rework
  * frontend: Minor consistency fixes
  * Fix deadlock of Popen.wait
  * frontend: Minor improvements for drive selection
- metainfo file name changed from *appdata.xml to *metainfo.xml
- Add dependency for new package vkbasalt-cli
* Wed Nov  2 2022 Marcus Rueckert <mrueckert@suse.de>
- We need python3-Pillow now.
* Sun Oct 16 2022 Imo Hester <vortex@z-ray.de>
- Updatede to version 2022.10.14.1
  * frontend: Improve wording for DXVK and VKD3D
  * frontend: Consistency improvements in Settings
  * frontend: Settings consistency improvements
  * frontend: Fix a silly typo
  * backend: Fix proton pfxs not showing in bottles list
  * frontend: Skip runner check on Steam proton pfxs
  * frontend: Improve vkbasalt wording
- Update to version 2022.10.14
  * The PulseAudio Latency setting is now deprecated and enabled by default
  * Add portal support for setting custom Bottles path thanks to @fries1234
  * Preferences now uses Generic names for better understanding
  * Improved Gamescope support
  * General improvements
  * Fix components mismatch on switching bottle
  * Fix unsafe access to the program"dict" keys
  * Fix unreachable newly-added programs
  * Fix for XDG_* vars being read by the runner even when not applicable
  * Fix charset error parsing acf files
  * Fix bottles list not being updated when removing a bottle
  * Fix empty secion in the Run Executable menu
  * French translations thanks to Thibaut Colin, @jay-tau
  * Dutch translations thanks to @flipflop97
  * Turkish translations thanks to @Zayria
  * Croatian translations thanks to @milotype
  * Bulgarian translations thanks to @RacerBG
  * Russian translations thanks to @lenemter
  * Bengali translations thanks to Anubis
  * Catalan translations thanks to @rogervc
* Wed Sep 28 2022 Imo Hester <vortex@z-ray.de>
- LICENSE is now called COPYING
* Wed Sep 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.9.28.1
  * fix components mismatch when switching bottle
- Update to version 2022.9.28
  * Nvidia-specific settings are now hidden on other setups
  * Run executables by dropping them on the bottle
  * Move from XML to Bluprints for UI
  * Mobile improvements
  * The Gamescope dialog is now more polished and intuitive
  * Display settings has now a dedicated dialog
  * All selectors are ported to the libadwaita
  * Support for ja_JP,zh_TW,ko_KR languages
  * Dependencies with an incompatible architecture are now hidden
  * Support for the bundled gstreamer version if provided by the runner
  * Adding a new program will be immediately available, without having to update the whole list
  * Removed the ability to install multiple dependencies in one go
  * Improve wording for Components section (Thanks to @orowith2os)
  * Fix DXVK off when starting a game via Run Executable
  * Fix a bug when extracting templates with a partial or missing userdir
  * Fix Steam installation not found when placed at .steam/debian-installation
  * Fix DLL OVerrides not being applied when an override with the same name is already present, now the new one will take priority
  * Fix Proton Runners being listed as prefixes
  * Fix GStreamer plugins not being loaded on Flatpak
  * Fix the bottles list not being updated when a bottle is renamed
  * Fix progressbar not being visible on some locales
  * Fix caching directories being re-initialized when them are already present
  * Fix Steam ACF files not being parsed correctly when corrupted, resulting in a crash
  * Fix Platinum and Silver grades was using the same color
  * Italian translations thanks to @LorenzoIanotto
  * Hindi translations thanks to Rowan Antkinson
  * Dutch translations thanks to @flipflop97
  * Turkish translations thanks to @06ergin06
  * Finnish translations thanks to Jiri Grönroos
  * Portuguese (Brazil) translations thanks to saulo marcos
  * Japanese translations thanks to @ryonakano
  * Croatian translations thanks to @milotype
  * Greek translations thanks to @kolyfotis
  * Indonesian translations thanks to @laymoth
* Tue Sep 27 2022 Imo Hester <vortex@z-ray.de>
- Fix: Dependencies
* Tue Sep 27 2022 Imo Hester <vortex@z-ray.de>
- Spec file cleaning
* Tue Aug 30 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.8.28-brescia-2
  * re-implement override_dll action
* Sun Aug 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.8.28-brescia-1
  * Fix stucks at loading in library view
* Sun Aug 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.8.28-brescia
  * Library mode is now a stable feature and enabled by default
  * Dependencies "copy_file" action now creates the path if not exists (see maintainers docs.)
  * Opening a bottle, a dialog is shown if the runner is not installed
  * The C: drive is now marked as persistend in the Drives section and cannot be edited by the user
  * All dialogs can now be closed pressing Escape
  * The dark mode switcher is now available only for system which doesn't support the standard
  * Simplification of "Legacy Tools" section, thanks to @Knebergish
  * Minor UI improvements, thanks to @TheEvilSkeleton, @orowith2os, @marhkb
  * Fix a bug in the template system, was trying to unpack a partial one
  * Fix a bug in setting overrides for old-structured program entries
  * Fix a bug in vmtouch management
  * Fix a bug in the WineCommand interface which was causing a crash if the executable path is not accessible
  * Fix a bug in the Steam Manager, was generating wrong shortcuts when the program name has spaces in it
  * Fix long names in library mode
  * Fix a bug in bottle creation, sometimes it created a symlinks loop in the userdir
  * Fix a bug in the crash dialog, the similarity check was set too high resulting in no similar reports
  * Italian translations thanks to @alfonso133
  * Bengali translations thanks to @zihadio
  * Catalan translations thanks to @rogervc
  * Tamil translations thanks to @kbdharun
  * Dutch translations thanks to @flipflop97
  * Spanish translations thanks to @ParadoxialN3
  * Ukranian translations thanks to @c0m1c5an5
  * Turkish translations thanks to @Dhizaes
* Fri Aug 19 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.8.14-brescia-1
  * Fix vmtouch_files attribute missing in WineCommand
  * Fix Error vmtouch mlock
  * Fix 'NoneType' object has no att
* Sun Aug 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.8.14-brescia
  * New vkBasalt settings, thanks to @TheEvilSkeleton
  * Support for vmtouch caching, thanks to @axtloss
  * New dark mode switch as fallback for distributions not supporting the freedesktop Dark Mode
  * Prevent programs from launching when clicking on the entry instead of the play button
  * Windows can now be closed by pressing Escape
  * The Library view now supports program settings overrides
  * "Add to Steam" and "Add Desktop Entry" now supports integrations (Epic, Ubisoft, etc.)
  * The bottles-cli "programs" option now list programs from integrations as well
  * Gamescope is now compatible with FSR
  * Minor UI improvements
  * Fix missing translations, thanks to @A6GibKm
  * Fix a bug in "Add to Steam", was not supporting ~/.steam
  * Fix a regression on renaming programs, this was causing duplicated entries
  * Fix a bug in the internal-sandbox, wine symlinks were not unlinked if the username had special characters
  * Fix a bug in generating desktop entries for programs with spaces in their names
  * Fix a bug in the copy_dll dependency action, wildcards were not handled correctly, thanks to @siroccal
  * Fix a bug in loading gstreamer libraries, were not respecting the bottle architecture
  * Fix a regression in library mode, adding a new program was causing a loop when the bottle name and path mismatched
* Tue Aug  9 2022 Imo Hester <vortex@z-ray.de>
- Added python-fvs
* Sun Jul 31 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.7.28-brescia-2
  * fix FSR support for gamescope
  * fix Adding a program to the library lets Bottles loading forever
  * fix Unable to launch bottles on Steam Deck
- Update to version  2022.7.28-brescia-1
  * fix regression in Offline mode
* Wed Jul 27 2022 Imo Hester <vortex@z-ray.de>
- Changed versioning scheme
- Update to version 2022.7.28-brescia
  * New versioning system which allow versioning the whole bottle (also configuration)
  * Automatic versioning can now be toggled on and off
  * Exclude paths from versioning using patterns
  * Use compression for versioning states
  * Improve Launch Options saving without update the UI multiple times
  * Improved YAML performance using libyaml (the python-yaml package must provide support for it)
  * New About dialog
  * Covers support in Library mode (thanks to SteamGridDB)
  * Removed DXVK HUD option, use the Environment Variables section instead
  * bottles-cli shell option now provide command output
  * The Health Check is now in the About´s Troubleshooting section
  * Extended Core dependencies check, packagers are invited to double-check their packages
  * New default permission for the Flatpak package: xdg-download
  * Added credits for Third-Party Libraries in the Credits section
  * Minor UI improvements
  * Fix for skipable onboard dialog
  * Fix for empty bottle name
  * Fix gstreamer libs for win32 bottles
  * Fix for RemoteDisconnected error causing a crash
  * Fix wrong Vaniglia listing
  * Fix templates being generated with symlinked paths causing loops
  * Fix configuration migration causing a crash when the user altered the configuration
  * Fix mscoree.dll not found
  * Fix regression for the -b option of the legacy bottles cli
  * Fix Steam Launch Options parser causing a crash
  * Fix a regression in the Add to Steam button not adding the new entry in Steam
* Sat Jul 16 2022 Imo Hester <vortex@z-ray.de>
- typelib-1_0-Adw-1 >= 1.2
* Sat Jul 16 2022 Imo Hester <vortex@z-ray.de>
- Raised required version of libadwaita-1-0 to >= 1.2 due to bottles using features of that version
- Updated to version 2022.7.14-brescia-3
  * fix "Add to Steam" (again)
- add python-icoextract to runtime dependencies
- Update to version 2022.7.14-brescia-2
  * fix "Add to Steam"
  * fix migration from old bottles config
- Update to version 2022.7.14-brescia-1
  * fix installers fail due to wrong ConfigManager handling
- Update to version 2022.7.14-brescia
  * New experimental feature: sandbox per bottle
  * Soda is the default runner based on Valve's Wine plus some TKG/GE patches
  * Installers has a new refreshed UI with more info and tracking process
  * Ubisoft Connect integration
  * Wine LoL runners are now unlocked in Flatpak
  * New "standalone" option in bottles-cli to generate a custom script for running programs in a bottle without passing though Bottles
  * Some performance improvements
  * New CLI download progress bar with speed, size and eta
  * New SteamManager which improve performances a bit
  * Improved UI for experimental library mode
  * Discovered Epic Games are now launched brought the Epic Games Store, using Cloud Sync and Anti cheat
  * Core dependencies are now checked on boot on non Flatpak packages
  * Now setting the env var DXVK_CONFIG_FILE=bottle_root will automatically point to the dxvk.conf file in the bottle root
  * Some dialogs improvements (thanks to @TheEvilSkeleton)
  * A dialog warning of the sandbox is shown by launching the first executable
  * Improved bottle template caching for smallest sizes
  * Runners now show a description of their purpose and composition
  * Minor UI improvements
  * Fix for broken templates not being re-generated
  * Fix dependencies keys not being removed on uninstall
  * Fix duplicated dependencies on re-install
  * Fix a regression in hiding auto-discovered programs
  * Fix a regression in adding entries to the library, were not supporting the new programs structure
  * Fix Wine-GE builds being detected as Proton builds (thanks to @nicobatty)
  * Fix a regression in the issues similarity check for the crash report dialog
  * Fix issue of being able to add colon to bottle name (thanks to @axtloss)
  * Fix issue of invisible checkbox in 'launch as terminal' dropdown (thanks to @axtloss)
  * Fix a bug in External_Programs migration when its structure was compromised
  * Fix duplicated programs when re-executing installers
  * Fix UI disappearing on two-finger swipe
  * Fix a regression in Environment Variables dialog not storing new entries on first save
  * Fix states not being displayed on first state generation
  * Fix regression in bottles-cli edit option
- Update to version 2022.6.28-brescia
  * Support for Steam Proton prefixes
  * Option to list programs from Epic Games Store
  * New path for shader cache (auto-migrated)
  * Mesa shader cache is now stored in the bottle
  * VKD3D shader cache is now stored in the bottle
  * Update Bottles Runtime to 0.5
  * Initial support for EAC Runtime
  * Initial support for Battleye Runtime
  * Improved speed on runner change using native method to stop the wineserver when stalled
  * Setting Windows version during bottle creation is now skipped when using Caffe
  * Support for adding new programs using bottle-cli
  * Programs are now stored with a unique ID, other ones will automatically be migrated on first launch
  * A disclaimer is shown when setting Proton as runner
  * Allow overriding cwd per program
  * Allow overriding/using FSR per program
  * Allow overriding PulseAudio latency per program
  * Allow overriding/using a virtual desktop per program
  * Cwd for programs with unix path is now automatically set to the executable root if not already defined
  * New option to choose the language for the programs running inside the bottle
  * Minor UI/UX improvements for better consistency
  * FORCE_OFFLINE=1 can be used to force-launching Bottles in offline mode
  * BOOT_TIME=1 can be used to benchmark Bottles' boot
  * Repositories update status is now displayed during boot
  * Programs overrides can now be reverted to the bottle's defaults using the dedicated option
  * Gamescope settings are now hidden when the utility is not available, thanks to @TheEvilSkeleton
  * Support for kgx terminal, thanks to @SuperSandro2000
  * Improve terminal emulators priorities (easyterm, user-installed, desktop bundled, others), thanks to @jtojnar
  * Fix missing icons when using custom themes
  * Fix bottles location for non-flatpak packages
  * Fix regression in DXVK-Nvapi for DLSS support
  * Fix wrong window decoration layout, thanks to @nahuelwexd
  * Fix for window freeze when menus are still open
  * Fix runtime download, was trying to update the one bundled with Flatpak
  * Fix desktop entry assistance dialog not showing up
  * Fix not saving DLL Overrides
  * Fix inconsistent runner choose when using the Custom environment
  * Fix regression on bottle creation which was allowing mono and gecko dialogs
  * Fix duplicate entries in installers view
  * Fix not saving Environment Variables
  * Fix path picker not showing for drives
  * Fix regression in versioning, drive_c were not updated
  * Fix Library not showing when a program is not found
  * Fix regression in Steam launch options, were not properly parsed
  * Fix for Gamescope when using MangoHud, thanks to @jntesteves
  * Fix for dependencies removal, causing a crash when the entry was manually removed from the bottle configuration file
* Thu Jul 14 2022 Imo Hester <vortex@z-ray.de>
- Update to require python 3.10
* Wed Jun  1 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.28-trento-3
  * New shell option for bottles-cli allowing launchers like itch.io working with Bottles
- Update to version 2022.5.28-trento-2
  * New action for dependencies: register_dll
- Update to version 2022.5.28-trento-1
  * Fix widget connection causing a crash
  * Fix latencyflex path not being created on start
- Update to version 2022.5.28-trento
  * Support for Steam runtimes (soldier, scout); if enabled, bottles with Proton use soldier while other runners use scout
  * Create Steam shortcuts directly from the program list; requires permission to the Steam path if Flatpak
  * Support for launching programs using xdg-open (e.g. xdg-open bottles:run/BottleName/ProgramName)
  * Library now show icons for all programs
  * Launch Bottles with a pre-selected bottle using the -b argument
  * Wine-GE runners are now grouped in the preferences
  * Improved logs readability
  * Disabled unsupported features for Steam Proton prefixes
  * Support for Nouveau drivers
  * Components installation now show a feedback during effective installation
  * Icon extraction now support external drives
  * Control WineProgram now support .cpl files
  * New WineProgram(s) Regsvr32, Eject, Expand, Explorer, Hh, Icinfo, Notepad, Oleview, Progman, Winhelp, Xcopy
  * Extended Msiexec WineProgram support with repair, uninstall, apply/uninstall patch, register/unregister module
  * The bottles list is now divided in categories (Bottles and Steam Proton prefixes)
  * General UI improvements
  * Fixed a bug which was preventing batch scripts from being executed via CLI
  * Fixed a bug during bottle creation which was raising an error when the recipe was empty
  * Fixed a bug in the journal which was causing a crash when the journal file was corrupted
  * Fixed a regression in sync change, the wine server was not being shut down properly
  * Fixed a bug in bottle preferences that caused a configuration update during widgets load
  * Fixed a bug which was preventing icoextract from working properly
  * Fixed a bug with desktop entries, were not being created if path contained apostrophes
  * Fixed a bug in setting the current working directory, it was being set even if it didn't exist
  * Fixed a bug in downloads, was causing a crash when the connection was closed by the server
  * Fixed a bug that sometimes caused a crash when offline
  * Fixed a bug with the Executor, it tried to execute even if the executable path was empty
  * Fixed a bug with Steam Proton prefixes support, was causing a crash if no prefixes were found
* Thu May 19 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.14-trento-3
  * Fix for nouveau drivers
  * Fix component download percentage
  * Fix icoextract not being spawned
  * Group Wine-GE runners in preferences
  * Show feedback for component installation
  * Support icon extraction from external drives
- Update to version 2022.5.14-trento-2
- Update to version 2022.5.14-trento-1
  * Fix for launching batch files triggering GUI
  * Fix for journal causing crash in case of corruption
  * Fix for the wine sync switch not stopping the wineserver in some cases
  * Open Bottles with a pre-selected bottle via legacy CLI (bottles -b BottlePathName)
  * Unimplemented features of Steam Proton prefix support are now hidden
* Sat May 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.14-trento
  * Downloads now show progress
  * Programs can now be added multiple times with different arguments/options
  * Added the ability to permanently remove programs from the list
  * Reworked program's menu
  * Path is now shown for custom scripts in programs launch options
  * Improve startup speed when launching programs from CLI
  * Some initial checks are now cached to improve startup speed
  * EasyTerm now allows you to copy and paste content
  * Improved Windows paths conversion using native methods
  * Desktop entries are now generated with the icon
  * An alert is shown when the user custom bottles path is not reachable
  * An alert is shown when the flatpak has no permissions to add desktop entries
  * Windows 95, 98 now available for 32-bit bottles
  * Programs list is now updated when an executable stops running
  * Health check now shows disk and memory info
  * LatencyFleX can now be installed from installers
  * Installers can now declare checks to make sure the program is installed before adding a new entry to the program list
  * Installers can now monitor the exit of executables before proceeding
  * Improved installation speed of DLL components (DXVK, vkd3d ..)
  * Dependencies can now import registry bundles
  * Fixed data.yml file not being reinitialized if empty
  * Fixed gnome-terminal support
  * Fixed encoding not being properly set when launching commands
  * Fixed launch options being ignored when launching from desktop entries
  * Fixed wrong tooltips in programs list
  * Fixed post scripts not being launched if the program fails to
  * Fixed a regression in launching executables from the file manager
  * Fixed a regression in versioning, was not checking for file recursively
  * Fixed sys-wine not being detected
  * Fixed program arguments not properly set when using gamemode or gamescope
  * Fixed issue with batch files not starting with path containing spaces
  * Fixed a bug with the backup manager, was causing with empty paths
  * Fixed a bug in the journal manager, was causing a crash if missing a key
  * Fixed a bug where parameters were not updated correctly when using installers that depend on other installers
  * Fixed a bug that caused dependencies not to show as installed starting from the second bottle
  * Fixed a bug with library not being reinitialized if empty
* Wed May 11 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.2-trento-3
  * Workaround to properly handle spaces in paths
  * Fixed a bug with the backup manager, was causing with empty paths
* Mon May  9 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.2-trento-2
  * Fixed a regression in versioning, was not checking for file recursively
  * Fixed a regression in launching executables from the file manager
  * Fix post-scripts, were not executed if the WineCommand fails
* Wed May  4 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.2-trento-1
  * Fix onboarding, crashing due to a mismatching page id
* Tue May  3 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.5.2-trento
  * General improvements to respect GNOME Circle requirements
  * More consistency of buttons/menus position
  * Improve Onboarding process
  * Auto-focus in bottle's name field when creating a new bottle
  * New bottle's name field now uses default style
  * New bottle create button is now always visible but disabled (not sensitive) if not usable
  * Improve end of bottle creation modal
  * Suggest how to install first program in new bottle
  * Explain what to do in each page
  * Explain what to do the first time you open a bottle
  * Bottle renaming is now in preferences view
  * Explain what compatibility grades are
  * Add missing dots to sentences
  * Fit title case
  * Align animations to most GNOME apps
  * Fixed desktop entries, bottles-cli was using Name instead of Path
* Thu Apr 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.4.28-trento
  * General UI improvements, make the interface more consistent and easier to use.
  * Support for bottles on different paths, the option is present in the custom env settings but is also respected by all the other envs
  * Notable general performance improvements of the WINE backend
  * Installers now supports the run_winecommand action, allowing you to run commands inside the prefix via WINE (refer to the maintainers documentation)
  * Dependencies now supports the delete_dlls action to remove a dll before updating (refers to the maintainers documentation)
  * Templates are now updated on bottle creation if newer components are detected, this will speed up the creation of new bottles
  * Desktop entries now uses the new CLI to launch the executable
  * The journal can now be browsed from Bottles, accessible from the Health check menu
  * The d3dx9 dependency (and more coming) now uses small archives, this speed up the installation
  * Windows paths are now launched via the Start WineProgram which set the current working directory to make sure it finds all files
  * Start WineProgram now tries to convert Unix paths to Windows if explicitly requested
  * The bottle's cwd preference has now a new button to reset to the default one
  * Desktop entries can now be updated, just press "Add Desktop Entry" again from the programs list
  * Updated samba to 4.15.6
  * Fixed flickering start/stop buttons in the programs list
  * Fixed a bug with Steam Launch options, which resulted in a crash when empty
  * Fixed a bug in the CLI, which could cause crashes due to the message handler
  * Fixed a bug with runners' libraries, some were not loaded in the environment
  * Fixed a bug with the Journal manager, was not creating the file on first launch
  * Fixed a bug with WineCmd WineProgram, spaces were not handled when launching batch scripts
  * Fixed a bug with DLL Components manager, in some conditions it could cause a crash when trying to handling a missing DLL
  * Fixed a bug with WinePath Wineprogam, paths were not escaped causing in wrong results
  * Fixed a bug in opening the file manager for a program, it did not support Windows paths
  * Fixed a bug in bottle naming, quotes were not always escaped
  * Fixed a bug with xterm, was disappearing after run
  * Fixed a bug with Steam Proton prefixes, those were not detected on some distributions
* Mon Apr 18 2022 Imo Hester <vortex@z-ray.de>
- Update to Version 2022.4.14-trento-2
  * Removed fallback download for winebridge (was causing a hang on some distributions)
  * Fix for xterm support
* Fri Apr 15 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.4.14-trento-1
  * Fixed a regression in bottles-cli
- Add: %%license LICENSE
- Add: %%doc README.md
- Add: Missing dependency python38-gobject-Gdk
* Thu Apr 14 2022 Imo Hester <vortex@z-ray.de>
- Removed manager.patch
- Removed unneeded build dependencies
- Update to version 2022.4.14-trento
  * The importer can find and import the default .wine prefix too
  * New experimental Library mode feature is now available
  * New Loading screen for startup
  * New option to restore hidden programs
  * The Versioning manager preserve symlinks
  * Working directory is now automatically set to the executable parent directory for manual launch
  * The experimental Steam Proton Prefixes now supports third-party libraries
  * The Direct3D renderer mode can now be changed from the bottle's preferences
  * The "Kill all" button now show a confirmation dialog
  * The DXVK version selection was removed when creating a custom bottle
  * DLL Components and Runners can be removed from Bottles' preferences
  * Support for obs-vkcapture
  * Support for VKBasalt
  * Small improvements
  * Fixed a bug with runner updates
  * Fixed a bug with initial components check
  * Fixed some missing translations
  * Fixed a bug with bottle creation during dependencies installation
  * Fixed a bug with gnome-terminal, spaces was not escaped
  * Fixed a bug with DLL components installation, was causing a crash on missing DLLs
  * Fixed a bug during Steam Proton prefixes update, was failing on missing launch options
* Mon Apr 11 2022 Imo Hester <vortex@z-ray.de>
- Reverted to python38 for Tumbleweed. This fixes boo#1198280
* Sun Apr 10 2022 Simon Vogl <simon.vogl@gmx.net>
- Change locale entry in the %%files section to avoid conflicts with the filesystem package
* Sun Apr  3 2022 Imo Hester <vortex@z-ray.de>
- Patched manager backend
- Update to version 2022.3.28-trento-1
  * Fixed a bug with runner update
- Update to version 2022.3.28-trento
  * Now it is possible to use custom environment recipes, just choose its YAML file when creating a new bottle
  * Support for Steam Runtime
  * Installers can now depend by other installers
  * Installers now uses Windows paths by default for new entries in the Programs list
  * Runners paths are now appended to the environment to ensure those to get picked up
  * The DXVK Hud option now uses the default configuration, use the Environment Variables section to tweak it
  * Now you can launch the game linked to a Steam Proton prefix directly from Bottles
  * Now enabling some options (e.g. MangoHud) for a Steam Proton prefix, the Launch options on Steam are updated (requires Steam restart)
  * Now Steam Proton prefixes are parsed from the vdf LocalSettings file
  * Now by updating the Launch options in a Steam Proton prefix, Bottles will read the changes and update the dedicated bottle
  * The ACO shader compiler has been removed from the preferences as it is active by default
  * Legacy WINE tools are now grouped in the Utilities menu
  * Now LatencyFleX will be used only with DXVK-Nvapi installed and the Vulkan layer is automatically appended to the environment, no need to set it manually
  * WineBridge is now automatically updated
  * Registry is now updated using the minimal WineCommand interface
  * New CLI much more powerful (bottles-cli --help)
  * Now Caffe is always the default runner when making a bottle with the Gaming or Application environment
  * Support for system Dark mode and general UI improvements (Thanks to @A6GibKm)
  * Better Download logging (Thanks to @thopiekar)
  * Fixed a bug when updating Core components
  * Fixed a bug in installing LatencyFleX, was causing a crash if there was no version selected
  * Fixed a bug with unix path when using CLI, was treated as a Windows path
  * Fixed a bug in the component version listing, the most recent version was not always picked up (Thanks to @CleoMenezesJr and @psydvl)
  * Fixed a bug with offline mode, connection check would not fail when stalled
  * Fixed a bug with changing the screen resolution, it wasn't async and caused a freeze
  * Fixed a bug with WineCommand, was using MangoHud on minimal mode too
  * Fixed a bug with Runner update, was not checking if the runner exist
* Mon Mar 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.3.14-trento-3
  * Fixed a bug of desktop entries with non-Windows path
* Mon Mar 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.3.14-trento-1
  * Auto-update winebridge on launch
  * Fixed a bug with LatencyFleX, was raising an error if no versions were available
* Mon Mar 14 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.3.14
  * MangoHud support (use org.freedesktop.Platform.VulkanLayer.MangoHud with flatpak)
  * Now installers provide a visual feedback if a checksum is wrong
  * Experimental support for Steam Proton prefixes (Flatpak need steam path permission)
  * Extended search and filters for installed programs
  * WinePath has now a WineProgram interface
  * Support for GE-Proton runners
  * Now starting executables is case insensitive
  * Added new screen resolutions in the dedicated menu
  * Now you can run other extensions as well, a program that supports them will be used if installed
  * Initial LatencyFleX support
  * Using the new repositories for components, dependencies and installers, should solve some countries restrictions problems seen with GitHub
  * WineBridge is now supported as core component (currently in testing), thanks to @pietrodicaprio
  * Flatpak is now based on org.winehq.Wine, thanks to @TheEvilSkeleton
  * Switchd from libnotify to GNotification, thanks to @A6GibKm
  * Kitty terminal is now supported, thanks to @Bartkk0
  * Foot terminal is now supported, thanks to @QuantMint
  * General improvements to the WINE backend
  * Fixed a bug with Konsole and xterm which was closing just after launching
  * Fixed a regression with Proton, Bottles was looking for the binaries in the wrong place
  * Fixed a bug in bottle creation, wineserver was not being awaited before update sync type
  * Fixed a bug with templates, if the build went wrong, the template was still stored and used for the next bottle
  * Fixed a bug with cabextract, was not supporting whitespaces in filenames
  * Fixed a bug in the journal, was crashing if a date was not set
  * Fixed a bug with layers, the executable path was not being set correctly
  * Fixed a bug during dependencies installation when it was not possible to read the repository index
  * Fixed a bug with DLL Components installation, a new layer was not being created if the bottle environment was Layered
  * Fixed a bug on runner change, the prefix was being updated before the new runner was set
  * Fixed a bug with dependencies installation, was failing if a file was already in place
  * Fixed a bug with CLI, Bottles was closing too early avoiding the program to be launched, thanks to @tgschultz
  * Fixed a bug with translations, some translations were not being loaded, thanks to @ryonakano
  * Fixed a bug with the about dialog, the close button was not working, thanks to @ryonakano
  * Fixed a bug with the notifications manager, was raising an error if there was just one notification
* Tue Mar  8 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.28-trento-4
  * Fixed a bug with Wine-GE runners, was using the wrong path for the binaries
  * Fixed a regression with offline mode
  * Fixed a bug with installers, was silently failing if checksum mismatch
  * Fixed a regression with Bottles CLI, programs with a Windows path did not run
* Mon Mar  7 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.28-trento-3
  * Fixed a bug with bottle creation (afflict only users who made a bottle with 2022.2.28-trento-2)
  * Support GE-Proton runners
  * Experimental Steam prefixes support (in early development)
* Wed Mar  2 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.28-trento-2
  * Templates are now validated to avoid storing broken prefixes
  * Fixed synchronization mismatch on bottle creation, will now wait for wineserver to shut down before changing synchronization type
* Mon Feb 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.28-trento-1
  * Fixed Proton compatibility (Bottles was looking for binaries in the wrong directories)
* Sun Feb 27 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.28-trento
  * Template caching creates a copy of the first bottle created with one environment, to use it as the basis of the next one, greatly reduces creation time. Templates are regenerated when a rule changes in the default configuration of an environment, while components are still updated if new ones are installed.
  * Now it is possible to install multiple dependencies at once (really not recommended)
  * The components screen has been reorganized into groups to make it easier to navigate
  * Change DPI directly from the bottle preferences
  * The Take focus option has added to preferences, allowing the user to resume focus on app change when these hold it
  * Improved WinePrograms logs with the effective running action
  * DXVK-async is now always at the bottom of the list, preventing it from being taken by Bottles as the most recent version on bottle creation
  * Add a journal file which collect all the most important actions and events
  * The userdir/ placeholder was added allowing maintainers to reach executables from the user bottle directory
  * New bottles are now sandboxed by default, despite if running as flatpak or not (in other packages the link to the user home is simply removed)
  * Manage your virtual drives directly from the bottle preferences
  * Programs list in bottle details is now hidden if there are only hidden entries
  * Flatpak users can now generate desktop entries too if the ~/.local/share/applications path is exposed
  * General improvements to the WINE backend
  * Fixed a problem with Windows version change, was trying to set duplicate keys on registry
  * Fixed a race condition on DLL components remove and install tasks (Thanks to @asbytes)
  * Fixed a bug in command execution, the WINEPREFIX env var was not rewritten if already present in the environment
  * Fixed DLL components for 32 bit bottles (Thanks to @ffuugoo)
  * Fixed a bug in Mouse Capture Fullscreen setting which was resetting on restart
  * Fixed a bug in backup export, the backup was not aborting if the user have not picked a path
  * Fixed a bug with generated desktop entries, was setting the wrong executable path
  * Fixed a bug in layered executables support, which was unable to launch executables due to structure mismatch
  * Fixed a bug with CabExtract implementation, which was extracting resources to the wrong directory if symlink
  * Fixed a bug in layer sweep function, which was sweeping all files instead of the different ones
  * Fixed a bug in layer mount function, which was mounting the wrong directory if reading from the configuration
  * Fixed a bug in WINE command execution, which was defaulting to the bottle path instead of the layered one
  * Fixed a bug in bottles initial check, which was causing a crash if the configuration file was not found
  * Fixed programs ignored_patterns, which was allowing unins* files to be listed in programs view
  * Fixed a bug with DLL components which was not ensuring the prefix was updated before registering DLL overrides
  * Fixed winbind issue (Thanks to @arashsm79)
  * Fixed a bug with hidden programs, which were not excluded from is_alive check
* Wed Feb 23 2022 Imo Hester <vortex@z-ray.de>
- Added typelib-1_0-GtkSource-4 as requirement
* Sun Feb 13 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.2.14-trento
  * Install programs in one-click using our community installers
  * Change default bottles location from preferences
  * New repositories manager makes fewer requests and takes less time to load
  * Runtime is now also available for non-Flatpak packages
  * Search in bottles list if there are at least 10 items
  * Automatically fallback to another runner if the system doesn't support Caffe 7+
  * Installers can now declare their architecture, so incompatible installers will not be shown
  * Dependencies can now be re-installed if something goes wrong
  * Programs can now be launched trough terminal right from the context menu
  * Task manager can now terminate processes
  * WINE Explorer now available from utilities
  * New userdir/ placeholder for installers to access sandboxed user directory
  * Improved Windows version switch, other keys are updated to ensure that programs detect the correct version
  * Improved health check dialog with syntax highlighting
  * General UI improvements for consistency
  * Introducing SystemComponents to handle unpackable components for non-Flatpak packages
  * Support DXVK-async as a component
  * Using XDG_DATA_HOME for default Bottles paths
  * Gamescope support in Flatpak
  * Fixed missing GtkSource namespace, was causing crashes
  * Fixed preferences regression, vkd3d was not displayed
  * Fixed a bug in Executor, was passing wrong arguments
  * Fixed a bug in WineCommand, was not getting the bottle parameters
  * Fixed a bug in components manager, was trying to remove non-existent files
  * Fixed a bug in DXVK version change, was removing the initial backup
  * Fixed a bug in installers, programs list was not updated immediately
  * Fixed a bug in programs list, uninstallers were not hidden
  * Fixed a bug in components manager, was causing crashes with not-known componnets
  * Fixed gamemode in Flatpak
  * Fixed a bug in WineCommand cwd, was not setting the value
  * Fixed a bug in Layered environment, layers key was set as list instead of dict
  * Fixed a bug in layered programs, was not able to launch due to wrong runtime configuration location
  * Fixed a bug in layered dependencies, tree was not updated correctly
  * Fixed a bug with config files, was causing exceptions with missing keys
  * Fixed a bug in update_config action, was try to handle a None value, providing a default value instead
* Fri Feb  4 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.1.28-trento-4
  * Fix missing GtkSourceview namespace
* Wed Feb  2 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.1.28-trento-3
  * fixes some dotnet packages
- Update to version 2022.1.28-trento-2
  * some windows versions was not properly set
- Update to version 2022.1.28-trento-1
  * Fix cwd for custom paths
  * Fix .lnk files launch
* Fri Jan 28 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.1.28
  * Each runner change will re-initialize the installed components (DXVK, VKD3D, DXVK-Nvapi ..) to avoid breackage
  * New WINE backend ensures stable and faster operations
  * New WINE registry WineProgram, allows to write multiple keys in a single call, reducing waiting times
  * New net WineProgram allows Bottles to manage bottle services
  * New wineserver WineProgram checks the bottle status to prevent commands from being executed when the server is down
  * New start/msiexec/cmd WineProgram(s) for handling .lnk shortcuts, .msi/.batch files
  * New executor manager handle all executables launched in Bottles, automatically redirecting the call to the correct WineProgram based on the extension
  * Choose a shell script to be executed after a program
  * Bottles handle 2 types of commands: minimal and full, allowing to run commands on lighter environments when needed (no gamescope, gamemode..)
  * Changing Windows/DXVK/VKD3D/DXVK-Nvapi/Runner version displays visual feedback
  * Support for Futex2 sync (need kernel 5.16 or patched)
  * Iinstallers can edit config files (json, ini, yaml) using the update_config action
  * Bottles shows in the console which WineProgram(s) are running
  * Manifests are now shown in a source view
  * Bottle detail page icon changed
  * Installers view now shows the pretty title and compatibility grade
  * Search in installers view
  * Hide and show items in the programs list
  * Rename auto-detected programs
  * Fixed Health Check crash in some distributions
  * Fixed Wayland support
  * Fixed unwanted program start ups when Bottles asks for the process list
  * Fixed 3D controller GPU detection
  * Fixed backup import feature
  * Fixed programs list, was disappearing after renaming a program
  * Fixed 64-bit dependencies installation, some actions was not able to place the DLLs in the correct folder
  * Fixed Windows version switch, some keys was missing causing some dependencies to fail to install (like .NET 3.5)
  * Fixed installers, was not interrupting the installation process when a dependency failed to install
  * Fixed bottle creation, was allowing some special characters in the name
  * Fixed Desktop entires, was setting the wrong path to the executable
  * Fixed the Download manager, was unable to reach some resources (e.g. physx) due to lack of User-Agent
  * Fixed dependencies installation during bottle creation, was breaking the bottle if a dependency is unreadable
  * Fixed a recursion in gamescope settings
  * Portuguese translations
  * Bulgarian translations
  * Italian translations
  * Portuguese (Brazil) translations
  * Sweedish translations
  * Basque translations
  * Greek translations
  * Croatian translations
  * Danish translations
  * Dutch translations
  * Polish translations
  * French translations
  * German translations
  * Spanish translations
  * Norwegian Bokmål translations
  * Indonesian translations
  * Turkish translations
  * Russian translations
  * Esperanto translations
  * Chinese (Simplified) translations
  * Finnish translations
  * Japanese translations
  * Czech translations
  * Hungarian translations
  * Chinese (Traditional) translations
  * Vietnamese translations
* Thu Jan 20 2022 Imo Hester <vortex@z-ray.de>
- Update to 2022.14.1-trento-4
  * fix win64 DLLs installation
* Mon Jan 17 2022 Imo Hester <vortex@z-ray.de>
- Added update for desktop file
- Removed unneeded dependencies to satisfy Lint warning
* Mon Jan 17 2022 Imo Hester <vortex@z-ray.de>
- Fixed build error due to comment
* Mon Jan 17 2022 Imo Hester <vortex@z-ray.de>
- Added more dependencies
* Mon Jan 17 2022 Imo Hester <vortex@z-ray.de>
- Added missing dependencies
* Mon Jan 17 2022 Imo Hester <vortex@z-ray.de>
- Added package compatibility for Leap 15.2 and 15.3
* Sun Jan 16 2022 Imo Hester <vortex@z-ray.de>
- Updated optional and required dependencies
* Sun Jan 16 2022 Imo Hester <vortex@z-ray.de>
- Raised required python3 version to 3.8 or later1
* Sun Jan 16 2022 Imo Hester <vortex@z-ray.de>
- Made package noarch
* Sun Jan 16 2022 Imo Hester <vortex@z-ray.de>
- Added missing required packages to spec
* Sun Jan 16 2022 Imo Hester <vortex@z-ray.de>
- Update to version 2022.1.14-trento-2:
  * fix wayland support
